######################
djangoCMS Education
######################

djangoCMS Education is a simple plugin for embedding your Resume in your website.

============
Installation
============


``pip install djangocms-education``


Add ``djangocms_education`` to your ``INSTALLED_APPS``

Run ``python manage.py migrate djangocms_education``
